## The open toolkit for building publishing workflows

<img src="pubsweet-logo.svg" style="width: 100%;max-width: 300px; display: block;margin: 1em auto;">

**PubSweet** is a free, open source framework for building state-of-the-art publishing platforms. PubSweet enables you to easily build a publishing platform tailored to your own needs. It is designed to be modular and flexible. PubSweet consists of a **server** (“back end”) and **client** (“front end”) that work together, and both can be modified and extended with **components** to add functionality to the system. There's also a **command-line tool** that helps manage PubSweet apps.

PubSweet is being used for book publishing, academic journal production, and micropublication platforms by a growing number of established academic organizations including the University of California Press, eLife, Hindawi, California Digital Library and others.

Each of these organizations is building their custom platform using PubSweet, and contributing reusable open source components back to the community. By drawing on this growing library of components, PubSweet can be used to rapidly create bespoke publishing systems. If the existing components do not completely meet your needs, you can focus development on building new components to provide just the new functionality required.

If someone has built an entire publishing platform which you like (for example, Editoria or xPub), you can use it as-is, or replicate then extend it, using your own ideas and components with minimal effort.

PubSweet is being used for book publishing, and academic journal production and preprint management services are in development. By drawing on the growing library of components, PubSweet can be used to rapidly create bespoke publishing systems. If the existing components don't completely meet your needs, you can focus development on building new components to provide just the new functionality needed. Join the PubSweet community and help us build a common resource of open components for publishing by contributing components back.

You can read more about the ideas behind PubSweet at the [Coko Foundation site](https://coko.foundation/technology/). If you would like to talk to anyone for help working with PubSweet you can find us all on the [Coko Chat](https://mattermost.coko.foundation).

This page was created using the awesome [React Styleguidist](https://github.com/styleguidist/react-styleguidist) and the [code that generates it can be found in our repository](https://gitlab.coko.foundation/pubsweet/pubsweet/tree/master/docs).

## Why does PubSweet exist?

Today most of the publishing systems are “big box” platforms built years ago when the world of publishing was different. They have not evolved at the same rate as users' needs and are largely just data stores that track rather than enable or manage workflow. Most of these systems are also expensive, monolithic, and proprietary, so it is very difficult to change them to meet your organization's needs. Inevitably the reverse happens and you must change your organization to meet the prescriptive worldview of the software. The PubSweet community believes that software should be working for us, not the other way around.

When using off-the-shelf software, changing a publisher's workflow means changing their organization or switching platform vendors. Both options are slow and expensive, making them undesirable. In the past, this has meant that the publishing sector has not been able to fully embrace the latest technological developments (for example, the web) or experiment and innovate in their workflows. When you cannot own or control your own tools, you have little say in what those tools allow you to do; consequently, you become subject to them, losing control of your publication process.

This lock-in can be avoided by giving the ownership of the tools back to publishers. PubSweet is built to do just that - it is an open source framework for building publishing workflows. This means you can build the workflows you want without compromising _and_ continually update and optimize them in the future.

## What are the benefits of PubSweet?

PubSweet is free Open Source software, so you don't have to pay to use it. You can modify it as much as you like, and use it for any purpose, including commercially and for-profit. The license (a popular and permissive open source licence called the MIT license) grants a perpetual right to use PubSweet in this way forever.

Thanks to the focus on modularity, you can extend PubSweet with components. You can add new components, extend existing components, or recompose a set of components on both the front end and back end as much as you like. You can leverage the existing components contributed to the community to lessen your development time and speed up your delivery.

<img src="pubsweet-components.svg" style="width: 100%;max-width: 1000px; display: block;margin: 1em auto;">

# Assemble your own PubSweet platform

PubSweet is web native so you can bring your workflow to the web. Bring your whole workflow, not just your published articles, into the web, the most powerful collaborative workflow instrument of our time.

Lastly, one of the most powerful reasons to use PubSweet is the Coko community. The ever-growing community of organizations building with and using PubSweet leads to a richer ecosystem with more components to draw from, and more resources to help you build your platform. By working together with the community, you can share the effort to produce new and exciting features, or reuse what someone else has built. Software that is already in use is likely to be more robust, free from defects, and well-adapted to real users. By participating in the community and sharing what you know, you will benefit from many others doing the same.
